/*
 * bt_loc_xml.h: bluetooth location services xml related functions header
 * Copyright 2003 by Columbia University; all rights reserved
 * Author: Howard Chu (hhc42@cs.columbia.edu)
 */

#ifndef BT_LOC_XML_H
#define BT_LOC_XML_H

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>

#define LOCATION_DOC_TYPE "locationinfo"

/*
 * xml_process_file()
 * Used by the client to parse the location file received from the server.
 * Right now, it extracts all the elements specified in the location xml
 * file schema and prints them to standard out.
 * file_name- the path of the file to be parsed
 * Returns 0 if succeed, -1 if fails
 */
int xml_process_file(char *file_name);

/*
 * xml_process_buffer
 * Used by the client to parse the location file received from the server.
 * Instead of taking in a file_name and parse the file, it takes in a
 * buffer and stores the buffer in the memory and parse through it.
 * Right now, it extracts all the elements specified in the location xml
 * file schema and prints them to standard out.
 * buffer- the xml buffer to be parsed
 * size- the size of hte buffer
 * Returns 0 if succeed, -1 if fails
 */
int xml_process_buffer(const char *buffer, int size);

/*
 * parse_co_ref_sys()
 * parse the coordinate reference system element of the location xml file
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_co_ref_sys(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_identifier()
 * parse the identifier element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_identifier(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_co_ref_sys()
 * parse the coordinate reference system element of the location xml file
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_co_ref_sys(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_identifier()
 * parse the identifier element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_identifier(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_geo_info()
 * parse the geo info element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_geo_info(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_pos()
 * parse the pos element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_pos(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_eme_pos()
 * parse the eme_pos element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_eme_pos(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_trl_pos()
 * parse the trl_pos element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_trl_pos(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_pd()
 * parse the pd element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_pd(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_poserr()
 * parse the poserr element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_poserr(xmlDocPtr doc, xmlNodePtr cur);

/*
 * parse_categorical()
 * parse the categorical element
 * xmlDocPtr doc- pointer to the xml document
 * xmlNodePtr cur- pointer to the current position in the document
 */
void parse_categorical(xmlDocPtr doc, xmlNodePtr cur);

#endif
